==> haskell-hslua-module-system-1.1.1-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-system.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-module-system
version:              1.1.1
visibility:           public
id:                   hslua-module-system-1.1.1-5nUC6gDvGBa6kTRmX0pEzc
key:                  hslua-module-system-1.1.1-5nUC6gDvGBa6kTRmX0pEzc
license:              MIT
copyright:            © 2019-2024 Albert Krewinkel <tarleb@hslua.org>
maintainer:           tarleb@hslua.org
author:               Albert Krewinkel
homepage:             https://github.com/hslua/hslua
synopsis:             Lua module wrapper around Haskell'\''s System module.
description:
    Provides access to system information and
    functionality to Lua scripts via Haskell'\''s `System`
    module.

    This package is part of HsLua, a Haskell framework
    built around the embeddable scripting language
    <https://lua.org Lua>.

category:             Foreign
abi:                  01b309647e5cfba7729a9ff61530dcc1
exposed:              True
exposed-modules:      HsLua.Module.System
hidden-modules:       HsLua.Module.SystemUtils
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-module-system-1.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-module-system-1.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-module-system-1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-system
hs-libraries:         HShslua-module-system-1.1.1-5nUC6gDvGBa6kTRmX0pEzc
depends:
    base-4.17.2.1 directory-1.3.7.1 exceptions-0.10.5
    hslua-core-2.3.1-42MeyWskp7m28w9nbHTnSC
    hslua-marshalling-2.3.1-1OCX1RaAq776jFXJrf9Og6
    hslua-packaging-2.3.1-EupQ0vB3XG1VQQLpwvImr
    temporary-1.3-8FAts4F1AmtHqh7aYyLCzN text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-system/html/hslua-module-system.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-system/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-module-system-1.1.1-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-system.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-module-system
version:              1.1.1
visibility:           public
id:                   hslua-module-system-1.1.1-KuEgenjHyVACCGkIL7Hmt7
key:                  hslua-module-system-1.1.1-KuEgenjHyVACCGkIL7Hmt7
license:              MIT
copyright:            © 2019-2024 Albert Krewinkel <tarleb@hslua.org>
maintainer:           tarleb@hslua.org
author:               Albert Krewinkel
homepage:             https://github.com/hslua/hslua
synopsis:             Lua module wrapper around Haskell'\''s System module.
description:
    Provides access to system information and
    functionality to Lua scripts via Haskell'\''s `System`
    module.

    This package is part of HsLua, a Haskell framework
    built around the embeddable scripting language
    <https://lua.org Lua>.

category:             Foreign
abi:                  03a75996217a53d0d2e75641ef0abd07
exposed:              True
exposed-modules:      HsLua.Module.System
hidden-modules:       HsLua.Module.SystemUtils
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-module-system-1.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-module-system-1.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-module-system-1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-system
hs-libraries:         HShslua-module-system-1.1.1-KuEgenjHyVACCGkIL7Hmt7
depends:
    base-4.17.2.1 directory-1.3.7.1 exceptions-0.10.5
    hslua-core-2.3.1-KHtQ1StPUFGgDZgoD7E0A
    hslua-marshalling-2.3.1-IgtCsiHhYGy5iz5DZtbSV9
    hslua-packaging-2.3.1-9uoqvhTbA4947oSISrR4wL
    temporary-1.3-8FAts4F1AmtHqh7aYyLCzN text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-system/html/hslua-module-system.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-system/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
